Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Location.

Actions, resources, and condition keys for Amazon Location - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Location

Amazon Location (service prefix: `geo` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Location
- Resource types defined by Amazon Location
- Condition keys for Amazon Location

## Actions defined by Amazon Location

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateTrackerConsumer | Grants permission to create an association between a geofence-collection and a tracker resource | Write | tracker* |  |
BatchDeleteGeofence | Grants permission to delete a batch of geofences from a geofence collection | Write | geofence-collection* |  |
BatchEvaluateGeofences | Grants permission to evaluate device positions against the position of geofences in a given geofence collection | Write | geofence-collection* |  |
BatchGetDevicePosition | Grants permission to send a batch request to retrieve device positions | Read | tracker* |  |
BatchPutGeofence | Grants permission to send a batch request for adding geofences into a given geofence collection | Write | geofence-collection* |  |
BatchUpdateDevicePosition | Grants permission to upload a position update for one or more devices to a tracker resource | Write | tracker* |  |
CreateGeofenceCollection | Grants permission to create a geofence-collection | Write | geofence-collection* |  |
CreateMap | Grants permission to create a map resource | Write | map* |  |
CreatePlaceIndex | Grants permission to create a place index resource | Write | place-index* |  |
CreateTracker | Grants permission to create a tracker resource | Write | tracker* |  |
DeleteGeofenceCollection | Grants permission to deletes a geofence-collection | Write | geofence-collection* |  |
DeleteMap | Grants permission to delete a map resource | Write | map* |  |
DeletePlaceIndex | Grants permission to delete a place index resource | Write | place-index* |  |
DeleteTracker | Grants permission to delete a tracker resource | Write | tracker* |  |
DescribeGeofenceCollection | Grants permission to retrieve a geofence collection details | Read | geofence-collection* |  |
DescribeMap | Grants permission to retrieve a map resource details | Read | map* |  |
DescribePlaceIndex | Grants permission to retrieve a a place-index resource details | Read | place-index* |  |
DescribeTracker | Grants permission to retrieve a tracker resource details | Read | tracker* |  |
DisassociateTrackerConsumer | Grants permission to remove the association between a tracker resource and a geofence-collection | Write | tracker* |  |
GetDevicePosition | Grants permission to retrieve the latest device position | Read | tracker* |  |
GetDevicePositionHistory | Grant permission to retrieve the device position history | Read | tracker* |  |
GetGeofence | Grants permission to retrieve the geofence details from a geofence-collection. | Read | geofence-collection* |  |
GetMapGlyphs | Grants permission to retrieve the glyph file for a map resource | Read | map* |  |
GetMapSprites | Grants permission to retrieve the sprite file for a map resource | Read | map* |  |
GetMapStyleDescriptor | Grants permission to retrieve the map style descriptor from a map resource | Read | map* |  |
GetMapTile | Grants permission to retrieve the map tile from the map resource | Read | map* |  |
GetMapTileJson | Grants permission to retrieves the map TileJSON details from a given map resource | Read | map* |  |
ListGeofenceCollections | Grants permission to lists geofence-collections | List |  |  |
ListGeofences | Grants permission to list geofences stored in a given geofence collection | Read | geofence-collection* |  |
ListMaps | Grants permission to list map resources | List |  |  |
ListPlaceIndexes | Grants permission to return a list of place index resources | List |  |  |
ListTrackerConsumers | Grants permission to retrieve a list of geofence collections currently associated to the given tracker resource | Read | tracker* |  |
ListTrackers | Grants permission to return a list of tracker resources | List |  |  |
PutGeofence | Grants permission to add a new geofence or update an existing geofence to a given geofence-collection | Write | geofence-collection* |  |
SearchPlaceIndexForPosition | Grants permission to reverse geocodes a given coordinate | Read | place-index* |  |
SearchPlaceIndexForText | Grants permission to geocode free-form text, such as an address, name, city or region | Read | place-index* |  |
UpdateGeofenceCollection | Grants permission to update the description of a geofence collection | Write | geofence-collection* |  |
UpdateTracker | Grants permission to update the description of a tracker resource | Write | tracker* |  |

## Resource types defined by Amazon Location

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
geofence-collection | `arn:$ { Partition}:geo:$ { Region}:$ { Account}:geofence-collection/$ { GeofenceCollectionName}` |
map | `arn:$ { Partition}:geo:$ { Region}:$ { Account}:map/$ { MapName}` |
place-index | `arn:$ { Partition}:geo:$ { Region}:$ { Account}:place-index/$ { IndexName}` |
tracker | `arn:$ { Partition}:geo:$ { Region}:$ { Account}:tracker/$ { TrackerName}` |

## Condition keys for Amazon Location

Location has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.